summaryrefslogtreecommitdiffstats
path: root/experimental/tqtinterface/qt4/src/sql/drivers/odbc/tqsql_odbc.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'experimental/tqtinterface/qt4/src/sql/drivers/odbc/tqsql_odbc.cpp')
-rw-r--r--experimental/tqtinterface/qt4/src/sql/drivers/odbc/tqsql_odbc.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/experimental/tqtinterface/qt4/src/sql/drivers/odbc/tqsql_odbc.cpp b/experimental/tqtinterface/qt4/src/sql/drivers/odbc/tqsql_odbc.cpp
index fda38a8e2..340143505 100644
--- a/experimental/tqtinterface/qt4/src/sql/drivers/odbc/tqsql_odbc.cpp
+++ b/experimental/tqtinterface/qt4/src/sql/drivers/odbc/tqsql_odbc.cpp
@@ -291,7 +291,7 @@ static TQString qGetStringData( STQLHANDLE hStmt, int column, int colSize, bool&
}
// if STQL_SUCCESS_WITH_INFO is returned, indicating that
// more data can be fetched, the length indicator does NOT
// contain the number of bytes returned - it tqcontains the
// total number of bytes that CAN be fetched
// colSize-1: remove 0 termination when there is more data to fetch
int rSize = (r == STQL_SUCCESS_WITH_INFO) ? (tqunicode ? colSize-2 : colSize-1) : lengthIndicator;
@@ -521,7 +521,7 @@ bool TQODBCPrivate::setConnectionOptions( const TQString& connOpts )
for ( TQStringList::ConstIterator it = raw.begin(); it != raw.end(); ++it ) {
TQString tmp( *it );
int idx;
- if ( (idx = tmp.tqfind( '=' )) != -1 )
+ if ( (idx = tmp.find( '=' )) != -1 )
connMap[ tmp.left( idx ) ] = tmp.mid( idx + 1 ).simplifyWhiteSpace();
else
qWarning( "TQODBCDriver::open: Illegal connect option value '%s'", tmp.latin1() );
@@ -863,7 +863,7 @@ TQVariant TQODBCResult::data( int field )
qWarning( "TQODBCResult::data: column %d out of range", field );
return TQVariant();
}
- if ( fieldCache.tqcontains( field ) )
+ if ( fieldCache.contains( field ) )
return fieldCache[ field ];
STQLRETURN r(0);
TQSTQLLEN lengthIndicator = 0;
@@ -963,8 +963,8 @@ TQVariant TQODBCResult::data( int field )
bool TQODBCResult::isNull( int field )
{
- if ( !fieldCache.tqcontains( field ) ) {
- // since there is no good way to tqfind out whether the value is NULL
+ if ( !fieldCache.contains( field ) ) {
+ // since there is no good way to find out whether the value is NULL
// without fetching the field we'll fetch it here.
// (data() also sets the NULL flag)
data( field );
@@ -1443,9 +1443,9 @@ bool TQODBCDriver::open( const TQString & db,
// Create the connection string
TQString connTQStr;
// support the "DRIVER={SQL SERVER};SERVER=blah" syntax
- if ( db.tqcontains(".dsn") )
+ if ( db.contains(".dsn") )
connTQStr = "FILEDSN=" + db;
- else if ( db.tqcontains( "DRIVER" ) || db.tqcontains( "SERVER" ) )
+ else if ( db.contains( "DRIVER" ) || db.contains( "SERVER" ) )
connTQStr = db;
else
connTQStr = "DSN=" + db;
@@ -291,7 +291,7 @@ static TQString qGetStringData( STQLHANDLE hStmt, int column, int colSize, bool&
// if STQL_SUCCESS_WITH_INFO is returned, indicating that
// more data can be fetched, the length indicator does NOT
- // contain the number of bytes returned - it tqcontains the
+ // contain the number of bytes returned - it contains the
// total number of bytes that CAN be fetched
// colSize-1: remove 0 termination when there is more data to fetch